==> blis-0.2.1.tar.gz: blis-0.2.1/blis/_src/kernels/knl/bli_kernels_knl.h <==
/*

   BLIS
   An object-based framework for developing high-performance BLAS-like
   libraries.

   Copyright (C) 2014, The University of Texas at Austin

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are
   met:
    - Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    - Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    - Neither the name of The University of Texas at Austin nor the names
      of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
   HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

GEMM_UKR_PROT( double,   s, gemm_knl_asm_24x16 )
GEMM_UKR_PROT( double,   d, gemm_knl_asm_24x8 )

PACKM_KER_PROT( double,   s, packm_knl_asm_24xk )
PACKM_KER_PROT( double,   s, packm_knl_asm_16xk )

PACKM_KER_PROT( double,   d, packm_knl_asm_24xk )
PACKM_KER_PROT( double,   d, packm_knl_asm_8xk )

// unused:
GEMM_UKR_PROT( double,   d, gemm_knl_asm_12x16 )
GEMM_UKR_PROT( double,   d, gemm_knl_asm_30x8 )
GEMM_UKR_PROT( double,   d, gemm_knl_asm_8x24 )

PACKM_KER_PROT( double,   d, packm_knl_asm_30xk )

==> blis-0.4.0.tar.gz: blis-0.4.0/blis/_src/kernels/knl/bli_kernels_knl.h <==
/*

   BLIS
   An object-based framework for developing high-performance BLAS-like
   libraries.

   Copyright (C) 2014, The University of Texas at Austin

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are
   met:
    - Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    - Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    - Neither the name(s) of the copyright holder(s) nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
   HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

GEMM_UKR_PROT( double,   s, gemm_knl_asm_24x16 )
GEMM_UKR_PROT( double,   d, gemm_knl_asm_24x8 )

PACKM_KER_PROT( double,   s, packm_knl_asm_24xk )
PACKM_KER_PROT( double,   s, packm_knl_asm_16xk )

PACKM_KER_PROT( double,   d, packm_knl_asm_24xk )
PACKM_KER_PROT( double,   d, packm_knl_asm_8xk )

// unused:
GEMM_UKR_PROT( double,   d, gemm_knl_asm_12x16 )
GEMM_UKR_PROT( double,   d, gemm_knl_asm_30x8 )
GEMM_UKR_PROT( double,   d, gemm_knl_asm_8x24 )

PACKM_KER_PROT( double,   d, packm_knl_asm_30xk )
